@@ -48,8 +48,8 @@
 #include <tdelocale.h>
 
 // TQt
-#include <ntqstring.h>
-#include <ntqstringlist.h>
+#include <tqstring.h>
+#include <tqstringlist.h>
 
 // Standard C/C++
 #include <vector>
