@@ -38,8 +38,8 @@
 #include <kstandarddirs.h>
 
 // TQt 
-#include <ntqcstring.h>
-#include <ntqmap.h>
+#include <tqcstring.h>
+#include <tqmap.h>
 
 // Standard C++ /C
 #include <list>
